# Quick Log Entry (qle)

*Markdown is to HTML as QLE is to ADIF*

Quick Log Entry format is a human readable and editable shorthand for
logging amateur radio contacts. `qle` is a tool for transforming log
files in Quick Log Entry format into Amateur Data Interchange Format
(ADIF).

## Project Coordinates

- Project Homepage and Downloads: [https://www.va2nw.ca/qle.html](https://www.va2nw.ca/qle.html)
- Development Sources: [https://codeberg.org/tcort/qle](https://codeberg.org/tcort/qle)

## Documentation

The file format is described in [doc/qle_format.md](doc/qle_format.md).

Additionally, man pages `qle(1)` and `qle_format(7)` are included with
the distribution.

## Requirements

Build dependencies:

* C compiler and standard build tools (`make`, `sh`, ...).

Runtime dependencies:

* `libc`

Maintainer dependencies:

* [autoconf](https://www.gnu.org/software/autoconf/)
* [automake](https://www.gnu.org/software/automake/)
* [help2man](https://www.gnu.org/software/help2man/)
* [ronn](https://github.com/rtomayko/ronn)

## Build Instructions

```
./configure
make
make check
make install
```

If no `configure` script is present, run `sh autogen.sh`.

## Converting from Quick Log Entry format to ADIF format

Normal usage:

```
qle log.qle log.adif
```

Compact ADIF output (one record per line, no header):

```
qle -c log.qle log.adif
```

Using the same log to generate ADIF for uploading to POTA and SOTA (Mt Philo
is POTA US-3134 and SOTA W1/GM-149):

```
qle --sota=W1/GM-149 log.qle VA2NW-20240807-sota.adif
qle --pota=US-3134   log.qle VA2NW-20240807-pota.adif
```

## Examples

Additional example input files are located in the `examples` directory of
this repository.

### POTA Logging

```
@VA2NW MYPOTA@CA-5004
20250315 CW 5W

14.064
1200 KJ5W  539 579 $TX
1202 N2PX  579 559 $NC
1205 AI3W  559 579 $NC
1207 W4TRA 559 449 $NC

7.034
1215 WA3TVH 559 559 $PA
1219 K1RDD  579 449 $MA
1220 WA2QLK 559 559 $NJ
```

### K1USN Slow Speed Test Logging

```
@VA2NW CW 32W 20250314

N6BP  21.03225   2009 !Bob  $FL {first SST contact on 15m with new antenna}
N3QE  14.0323685 2012 !Tim  $MD
K1SEI  7.032525  2015 !Tage $CT
```

## Versioning

Version numbers for the `qle` tool follow [Semantic Versioning](https://semver.org/).

## Software License

The software is released under the [GNU General Public License](https://www.gnu.org/licenses/gpl-3.0.en.html)
as published by the Free Software Foundation, either version 3 of the License,
or (at your option) any later version. See `COPYING.md` for details.

## Credits

Quick Log Entry (qle) was inspired by Fast Log Entry (FLE) - Version 3.

Quick Log Entry (qle) was developed by the people listed in [AUTHORS.md](AUTHORS.md)

## README.md License

SPDX-License-Identifier: FSFAP

```
Copyright 2025 Thomas Cort

Copying and distribution of this file, with or without modification, are
permitted in any medium without royalty, provided the copyright notice and
this notice are preserved. This file is offered as-is, without any warranty.
```
