qle_format(7) -- Quick Log Entry Format
=======================================

## DESCRIPTION

Quick Log Entry is a shorthand for logging amateur radio contacts.

## SYNTAX

### Field Types

There are a few different types of fields.

- **enumerations**: one of several fixed strings. For example, mode has possible values like `CW`, `SSB`, etc. Example: `CW`.
- **prefix**: a special character or sequence of characters followed by a value. For example, station callsign is preceded by `@`. Example: `@VA2NW`.
- **suffix**: a value followed by a special character or sequence of characters. For example, transmit power is an integer or floating point number followed by `W`. Example: `32W`
- **pattern**: a value that matches a given pattern. For example, the QSO data is 8 digits. Example: `20251231`.
- **enclosure**: a starting character followed by the value followed by the corresponding ending character. For example, QSO notes begin with `{` and end `}` and have the note in the middle. Example: `{This is a note}`.

### Field Separators

Fields are delimited by white space (spaces, tabs, newlines, etc).

### Field Order

The order of fields does not matter except for RST. The RST sent is specified
first and the RST received is specified second. For example: `449 539` means
RST sent is `449` and RST received is `539`.

### Ending a QSO Record

Every line with the contacted station's callsign will cause one ADIF record to
be produced. Thus, there can only be at most one callsign on a given line.

### Persistent vs Ephemeral

Some values are persistent and are remembered across QSOs. For example, the
mode is persistent. If the mode is specified, the current QSO as well as
subsequent QSOs will have the given mode until the mode is specified again.

Some value are ephemeral and are not remembered across QSOs. For example, the
contacted station operator's name is ephemeral. If the name is specified, the
current QSO will have the given name. It will be forgotten. Any subsequent
QSOs where a name is to be logged will need to specify a name.

### Field: QSO Mode

- **Form**: enumeration
- **Possible Values**: `AM`, `ARDOP`, `ATV`, `CHIP`, `CLO`, `CONTESTI`, `CW`, `DIGITALVOICE`, `DOMINO`, `DYNAMIC`, `FAX`, `FM`, `FSK441`, `FT8`, `HELL`, `ISCAT`, `JT4`, `JT6M`, `JT9`, `JT44`, `JT65`, `MFSK`, `MSK144`, `MT63`, `OLIVIA`, `OPERA`, `PAC`, `PAX`, `PKT`, `PSK`, `PSK2K`, `Q15`, `QRA64`, `ROS`, `RTTY`, `RTTYM`, `SSB`, `SSTV`, `T10`, `THOR`, `THRB`, `TOR`, `V4`, `VOI`, `WINMOR`, `WSPR`
- **Default**: `CW`
- **Persistence**: persistent
- **ADIF Field**: `MODE`
- **Example**: `CW`

### Field: UTC Date on which the QSO started (and optionally ended)

- **Form**: pattern
- **Pattern**: `YYYYMMDD` or `YYYYMMDD-YYYYMMDD`
- **Default**: none
- **Persistence**: persistent qso date, ephemeral qso date off
- **ADIF Field**: `QSO_DATE`/`QSO_DATE_OFF`
- **Example**: `20251231` or `20251231-20260101`

### Field: UTC Time on which the QSO started (and optionally ended)

- **Form**: pattern
- **Pattern**: `HHMM` or `HHMMSS` or `HHMM-HHMM` or `HHMMSS-HHMMSS` or `HHMM-HHMMSS` or `HHMMSS-HHMM`
- **Default**: none
- **Persistence**: persistent time on, ephemeral time off
- **ADIF Field**: `TIME_ON`/`TIME_OFF`
- **Example**: `1620` or `162030` or `162030-162310` or `162031-1631` or `1620-163120`
- **Notes**: a time alone or a time before the `-` is the time on, a time after the `-` is the time off.

### Field: Logging station's power in Watts

- **Form**: suffix
- **Pattern**: integer or decimal number
- **Suffix**: `W`
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `TX_PWR`
- **Example**: `1.5W` or `5W`

### Field: QSO frequency in Megahertz

- **Form**: pattern
- **Pattern**: decimal number
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `FREQ`/`BAND`
- **Example**: `14.069`

### Field: Logging station's callsign

- **Form**: prefix
- **Prefix**: `@`
- **Pattern**: callsign
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `STATION_CALLSIGN`
- **Example**: `@AC1PH`

### Field: Logging operator's callsign

- **Form**: prefix
- **Prefix**: `%`
- **Pattern**: callsign
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `OPERATOR`
- **Example**: `%VA2EPR`

### Field: Contacted station's callsign

- **Form**: pattern
- **Pattern**: callsign
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `CALL`
- **Example**: `VA2EPR`

### Field: Contacted station's operator's callsign

- **Form**: prefix
- **Prefix**: `^`
- **Pattern**: callsign
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `CONTACTED_OP`
- **Example**: `^AC1PH`

### Field: Contacted station's operator's name

- **Form**: prefix
- **Prefix**: `!`
- **Pattern**: any characters except white space
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `NAME`
- **Example**: `!Arthur`

### Field: Contacted station's primary administrative subdivision

- **Form**: prefix
- **Prefix**: `$`
- **Pattern**: any characters except white space
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `STATE`
- **Example**: `$QC`

### Field: Contacted station's Straight Key Century Club (SKCC) member number

- **Form**: prefix
- **Prefix**: `#`
- **Pattern**: digits optionally followed by `S`, `T`, or `C`
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `SKCC`
- **Example**: `#4889T`

### Field: Contest QSO transmitted information

- **Form**: prefix
- **Prefix**: `,`
- **Pattern**: any characters except white space
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `STX_STRING`
- **Example**: `,OTS`

### Field: Contest QSO received information

- **Form**: prefix
- **Prefix**: `.`
- **Pattern**: any characters except white space
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `SRX_STRING`
- **Example**: `.VT`

### Field: QSO notes (information of interest to the logging station's operator)

- **Form**: enclosure
- **Prefix**: `{`
- **Pattern**: any characters except `}`
- **Suffix**: `}`
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `NOTES`
- **Example**: `{Meme Appreciation Month Special Event Station}`

### Field: QSO comments (information of interest to the contacted station's operator)

- **Form**: enclosure
- **Prefix**: `<`
- **Pattern**: any characters except `>`
- **Suffix**: `>`
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `COMMENT`
- **Example**: `<signal has a 60 Hz hum>`

### Field: QSL Message (a message for the contacted station's operator)

- **Form**: enclosure
- **Prefix**: `[`
- **Pattern**: any characters except `]`
- **Suffix**: `]`
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `QSLMSG`
- **Example**: `[QSL via LoTW or Direct w/SASE]`

### Field: Contacted station's POTA reference

- **Form**: prefix
- **Prefix**: `POTA@`
- **Pattern**: reference
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `SIG`, `SIG_INFO`
- **Example**: `POTA@CA-0498`

### Field: Logging station's POTA reference

- **Form**: prefix
- **Prefix**: `MYPOTA@`
- **Pattern**: reference
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `MY_SIG`, `MY_SIG_INFO`
- **Example**: `MYPOTA@CA-5082`

The prefix on its own (`MYPOTA@`) without a reference will clear the persisted
value.

### Field: Contacted station's SOTA reference

- **Form**: prefix
- **Prefix**: `SOTA@`
- **Pattern**: reference
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `SIG`, `SIG_INFO`
- **Example**: `SOTA@W1/CB-010`

### Field: Logging station's SOTA reference

- **Form**: prefix
- **Prefix**: `MYSOTA@`
- **Pattern**: reference
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `MY_SIG`, `MY_SIG_INFO`
- **Example**: `MYSOTA@W1/GM-049`

The prefix on its own (`MYSOTA@`) without a reference will clear the persisted
value.

### Field: Contacted station's WWFF reference

- **Form**: prefix
- **Prefix**: `WWFF@`
- **Pattern**: reference
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `SIG`, `SIG_INFO`
- **Example**: `WWFF@VEFF-0498`

### Field: Logging station's WWFF reference

- **Form**: prefix
- **Prefix**: `MYWWFF@`
- **Pattern**: reference
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `MY_SIG`, `MY_SIG_INFO`
- **Example**: `MYWWFF@VEFF-0498`

The prefix on its own (`MYSOTA@`) without a reference will clear the persisted
value.

### Field: Contacted station's IOTA designator

- **Form**: prefix
- **Prefix**: `IOTA@`
- **Pattern**: reference
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `IOTA`
- **Example**: `IOTA@NA-136`

### Field: Logging station's IOTA designator

- **Form**: prefix
- **Prefix**: `MYIOTA@`
- **Pattern**: reference
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `MY_IOTA`
- **Example**: `MYIOTA@NA-136`

### Field: Contacted station's CQ Zone

- **Form**: prefix
- **Prefix**: `cqz@`
- **Pattern**: CQ Zone
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `CQZ`
- **Example**: `cqz@5`

### Field: Logging station's CQ Zone

- **Form**: prefix
- **Prefix**: `mycqz@`
- **Pattern**: CQ Zone
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `MY_CQ_ZONE`
- **Example**: `mycqz@5`

### Field: Contacted station's ITU Zone

- **Form**: prefix
- **Prefix**: `ituz@`
- **Pattern**: ITU Zone
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `ITUZ`
- **Example**: `ituz@4`

### Field: Logging station's ITU Zone

- **Form**: prefix
- **Prefix**: `myituz@`
- **Pattern**: ITUZ Zone
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `MY_ITU_ZONE`
- **Example**: `myituz@4`

### Field: Contacted station's Maidenhead Grid Square

- **Form**: prefix
- **Prefix**: `grid@`
- **Pattern**: gridsquare
- **Default**: none
- **Persistence**: ephemeral
- **ADIF Field**: `GRIDSQUARE`
- **Example**: `grid@FN25ck`

### Field: Logging station's Maidenhead Grid Square

- **Form**: prefix
- **Prefix**: `mygrid@`
- **Pattern**: gridsquare
- **Default**: none
- **Persistence**: persistent
- **ADIF Field**: `MY_GRIDSQUARE`
- **Example**: `mygrid@FN25ck`

### Field: Signal report sent to the contacted station

- **Form**: pattern
- **Pattern**: 1 to 5 followed by 1 to 9 optionally followed by 1 to 9
- **Default**: `599` when mode is `CW` otherwise `59`
- **Persistence**: ephemeral
- **ADIF Field**: `RST_SENT`
- **Example**: `439`
- **Notes**: the first instance of a value matching the pattern sets this value.

### Field: Signal report received from the contacted station

- **Form**: pattern
- **Pattern**: 1 to 5 followed by 1 to 9 optionally followed by 1 to 9
- **Default**: `599` when mode is `CW` otherwise `59`
- **Persistence**: ephemeral
- **ADIF Field**: `RST_RCVD`
- **Example**: `53`
- **Notes**: the second instance of a value matching the pattern sets this value.

## VERSION

This document describes version 1.2.2 of the Quick Log Entry format.

Version numbers for Quick Log Entry format follow [Semantic Versioning](https://semver.org/).

## COPYRIGHT

SPDX-License-Identifier: FSFAP

```
Copyright 2025 Thomas Cort

Copying and distribution of this file, with or without modification, are
permitted in any medium without royalty, provided the copyright notice and
this notice are preserved. This file is offered as-is, without any warranty.
```

## SEE ALSO

qle(1)
