/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>

#include "args.h"

void qle_help(void) {
	fprintf(stdout, "Quick Log Entry format is a human readable and editable\n");
	fprintf(stdout, "shorthand for logging amateur radio contacts. `qle' is\n");
	fprintf(stdout, "a tool for transforming log files in Quick Log Entry\n");
	fprintf(stdout, "format into Amateur Data Interchange Format (ADIF).\n");
	fprintf(stdout, "This version of the tool supports the following formats: \n");
	fprintf(stdout, "Quick Log Entry format %s -> ADIF format %s\n", QLE_VERSION, ADIF_VERSION);
	fprintf(stdout, "\n");
	fprintf(stdout, "If [OUTPUT_FILE] does not exist, it is created.\n");
	fprintf(stdout, "If [OUTPUT_FILE] does exist, the `qle' output is appended to the file.\n");
	fprintf(stdout, "\n");
	qle_usage();
	fprintf(stdout, "\n");
	fprintf(stdout, "Options:\n");
	fprintf(stdout, "\n");
	fprintf(stdout, "  -a, --after=WHEN   Only output QSOs after a given date/time in the format: YYYY[MM[DD[HH[mm[ss]]]]]\n");
	fprintf(stdout, "  -b, --before=WHEN  Only output QSOs before a given date/time in the format: YYYY[MM[DD[HH[mm[ss]]]]]\n");
	fprintf(stdout, "  -c, --overwrite    If [OUTPUT_FILE] exists, truncate it and create a new file rather than appending to the existing file.\n");
	fprintf(stdout, "  -f, --format=FMT   Format output in a specific way. Allowed formats: default, compact, cabrillo\n");
	fprintf(stdout, "  -h, --help         Print help information and exit\n");
	fprintf(stdout, "  -n, --no-header    Suppress header output\n");
	fprintf(stdout, "  -p, --pota=REF     Simulate MYPOTA@${REF} before processing input\n");
	fprintf(stdout, "  -s, --sota=REF     Simulate MYSOTA@${REF} before processing input\n");
	fprintf(stdout, "  -V, --version      Print version information and exit\n");
	fprintf(stdout, "  -w, --wwff=REF     Simulate MYWWFF@${REF} before processing input\n");
	fprintf(stdout, "\n");
	fprintf(stdout, "Examples:\n");
	fprintf(stdout, "\n");
	fprintf(stdout, "  qle log.qle log.adif			Transform log.qle into log.adif\n");
	fprintf(stdout, "  qle -f compact log.qle log.adif	Transform log.qle into log.adif using a more compact ADIF (one record per line, no header).\n");
	fprintf(stdout, "  qle -s VE2/OU-014 log.qle log.adif	Transform log.qle into log.adif and set MY_SOTRA_REF, MY_SIG, and MY_SIG_INFO for VE2/OU-014 SOTA Summit.\n");
	fprintf(stdout, "\n");
	fprintf(stdout, "Report bugs to <%s>\n", PACKAGE_BUGREPORT);
}

void qle_version(void) {
	fprintf(stdout, "%s\n", PACKAGE_STRING);
	fprintf(stdout, "%s\n", COPYRIGHT);
	fprintf(stdout, "%s\n", LICENSE);
	fprintf(stdout, "\n");
	fprintf(stdout, "Written by %s\n", AUTHOR);
}

void qle_usage(void) {
	fprintf(stdout, "Usage: qle [OPTIONS] [INPUT_FILE] [OUTPUT_FILE]\n");
}

