/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef QLE_CABRILLO_H
#define QLE_CABRILLO_H

#include <stdio.h>

#define QLE_CABRILLO_EOL "\r\n"

enum qle_cabrillo_template_type {
	QLE_CABRILLO_TEMPLATE_DONE,
	QLE_CABRILLO_TEMPLATE_CHOICE,
	QLE_CABRILLO_TEMPLATE_TEXT,
};

struct qle_cabrillo_quiz_text_args {
	char *pattern;
};

struct qle_cabrillo_quiz_choice_args {
	char **choices;
};

union qle_cabrillo_template_args {
	struct qle_cabrillo_quiz_text_args text;
	struct qle_cabrillo_quiz_choice_args choice;
};

struct qle_cabrillo_template {
	enum qle_cabrillo_template_type type;
	char *tag;
	char *question;
	union qle_cabrillo_template_args args;
};

void qle_cabrillo_write_tag(FILE *output, char *tag, char *value);
int qle_cabrillo_quiz_text(FILE *output, char *tag, char *question, char *pattern);
int qle_cabrillo_quiz_choice(FILE *output, char *tag, char *question, char *choices[]);
int qle_cabrillo_header(FILE *input, FILE *output, FILE *error);
char *qle_cabrillo_date(void);
char *qle_cabrillo_mode(void);
char *qle_cabrillo_freq(void);
void qle_cabrillo_record(FILE *output);
void qle_cabrillo_footer(FILE *output);

#endif
