/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdlib.h>
#include <string.h>

#include "adif.h"
#include "cabrillo.h"
#include "fmt.h"
#include "parse.h"
#include "str.h"
#include "util.h"

int qle_qso_datetime_is_after(char *after) {

	int i;
	char qso_datetime[15] /* strlen("YYYYMMDDHHmmss") + '\0' */;
	qle_strnlcpy(qso_datetime, "00000000000000", 15, 0, 14);

	memcpy(qso_datetime,     qle_fields[QLE_FIELD_INDEX_QSO_DATE].value, qle_min(strlen(qle_fields[QLE_FIELD_INDEX_QSO_DATE].value), 8));
	memcpy(qso_datetime + 8, qle_fields[QLE_FIELD_INDEX_TIME_ON].value,  qle_min(strlen(qle_fields[QLE_FIELD_INDEX_TIME_ON].value),  6));

	return strcmp(qso_datetime, after) > 0;
}

int qle_qso_datetime_is_before(char *before) {

	int i;
	char qso_datetime[15] /* strlen("YYYYMMDDHHmmss") + '\0' */;
	qle_strnlcpy(qso_datetime, "00000000000000", 15, 0, 14);

	memcpy(qso_datetime,     qle_fields[QLE_FIELD_INDEX_QSO_DATE].value, qle_min(strlen(qle_fields[QLE_FIELD_INDEX_QSO_DATE].value), 8));
	memcpy(qso_datetime + 8, qle_fields[QLE_FIELD_INDEX_TIME_ON].value,  qle_min(strlen(qle_fields[QLE_FIELD_INDEX_TIME_ON].value),  6));

	return strcmp(qso_datetime, before) < 0;
}


int qle_fmt_header(enum qle_fmt_t fmt, FILE *input, FILE *output, FILE *error, time_t input_mtime, char *input_file) {

	switch (fmt) {
		case QLE_FMT_ADIF:
			qle_adif_header(output, input_mtime, input_file);
			return 0;
		case QLE_FMT_ADIF_NO_HEADER:
			/* nothing to do */
			return 0;
		case QLE_FMT_ADIF_COMPACT:
			/* nothing to do */
			return 0;
		case QLE_FMT_CABRILLO:
			return qle_cabrillo_header(input, output, error);
		default:
			fprintf(error, "Unrecognized output format\n");
			return -1;
	}
}

void qle_fmt_record(enum qle_fmt_t fmt, FILE *output, char *after, char *before) {
	int i;

	if (qle_fields[QLE_FIELD_INDEX_CALL].value[0] == '\0') {
		return; /* no call sign nothing to do */
	}

	if (qle_qso_datetime_is_after(after) && qle_qso_datetime_is_before(before)) {

		switch (fmt) {
			case QLE_FMT_ADIF:
				qle_adif_record(output, 0);
				break;
			case QLE_FMT_ADIF_COMPACT:
				qle_adif_record(output, 1);
				break;
			case QLE_FMT_ADIF_NO_HEADER:
				qle_adif_record(output, 0);
				break;
			case QLE_FMT_CABRILLO:
				qle_cabrillo_record(output);
				break;
			default:
				break;
		}

	}

	for (i = 0; i < QLE_NFIELDS; i++) {
		if (qle_fields[i].preserve == 0) {
			memset(qle_fields[i].value, '\0', QLE_TOKEN_SIZE);
		}
	}
	qle_rst_defaults();
}

void qle_fmt_footer(enum qle_fmt_t fmt, FILE *output) {

	switch (fmt) {
		case QLE_FMT_ADIF:
			/* nothing to do here */
			break;
		case QLE_FMT_ADIF_COMPACT:
			/* nothing to do here */
			break;
		case QLE_FMT_ADIF_NO_HEADER:
			/* nothing to do here */
			break;
		case QLE_FMT_CABRILLO:
			qle_cabrillo_footer(output);
			break;
		default:
			break;
	}
}
