/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "re.h"
#include "str.h"
#include "quiz.h"

int qle_quiz_text(char *question, char *pattern, char *result, int result_len) {

	char *p;

	do {

		fprintf(stdout, "\nQUESTION: %s\n", question);
		fprintf(stdout, "\nANSWER> ");
		fflush(stdout);

		memset(result, '\0', result_len);
		p = fgets(result, result_len - 1, stdin);
		if (p == NULL) {
			return -1;
		}

		qle_trim(result);

		if (qle_match(result, pattern) == 1) {
			break;
		}
		fprintf(stderr, "Invalid input. Please try again\n\n");

	} while (1);

	return 0;
}

int qle_quiz_choice(char *question, char *choices[]) {

	int i;
	int choice;
	int nchoices;
	char *p;
	char buffer[64];

	do {

		fprintf(stdout, "\nQUESTION: %s\n", question);
		fprintf(stdout, "\n");

		nchoices = 0;
		for (i = 0; choices[i] != NULL; i++) {
			fprintf(stdout, "%d) %s\n", i + 1, choices[i]);
			nchoices = nchoices + 1;
		}

		fprintf(stdout, "\nANSWER> ");
		fflush(stdout);

		memset(buffer, '\0', 64);
		p = fgets(buffer, 63, stdin);
		if (p == NULL) {
			return -1;
		}

		qle_trim(buffer);

		choice = 0;
		choice = atoi(buffer);
		choice--;

		if (choice >= 0 && choice < nchoices) {
			break;
		}
		fprintf(stderr, "Invalid choice. Please enter a number between 1 and %d\n\n", nchoices);

	} while (1);

	return choice;
}
