/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>

#include "cabrillo.h"
#include "tmpl_cq_wpx_cw.h"

/* https://www.cqwpx.com/cabrillo.htm */

static char *qle_tmpl_cq_wpx_cw_category_operator[] = {
	"SINGLE-OP",
	"MULTI-OP",
	"CHECKLOG",
	NULL
};

static char *qle_tmpl_cq_wpx_cw_category_assisted[] = {
	"ASSISTED",
	"NON-ASSISTED",
	NULL
};

static char *qle_tmpl_cq_wpx_cw_category_mode[] = {
	"SSB",
	"CW",
	NULL
};

static char *qle_tmpl_cq_wpx_cw_category_band[] = {
	"ALL",
	"160M",
	"80M",
	"40M",
	"20M",
	"15M",
	"10M",
	NULL
};

static char *qle_tmpl_cq_wpx_cw_category_power[] = {
	"HIGH",
	"LOW",
	"QRP",
	NULL
};

static char *qle_tmpl_cq_wpx_cw_category_transmitter[] = {
	"ONE",
	"TWO",
	"UNLIMITED",
	NULL
};

static char *qle_tmpl_cq_wpx_cw_certificate[] = {
	"YES",
	"NO",
	NULL
};

struct qle_cabrillo_template qle_tmpl_cq_wpx_cw[] = {
	{
		.type = QLE_CABRILLO_TEMPLATE_TEXT,
		.tag = "CALLSIGN",
		.question = "Which callsign was used during the contest?",
		.args = {
			.text = {
				.pattern = "^([A-Z0-9])+$"
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-BAND",
		.question = "Which band category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_cq_wpx_cw_category_band
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-MODE",
		.question = "Which mode category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_cq_wpx_cw_category_mode
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-OPERATOR",
		.question = "Which operator category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_cq_wpx_cw_category_operator
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-POWER",
		.question = "Which power category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_cq_wpx_cw_category_power
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-TRANSMITTER",
		.question = "Which transmitter category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_cq_wpx_cw_category_transmitter
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-ASSISTED",
		.question = "Which assisted category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_cq_wpx_cw_category_assisted
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_TEXT,
		.tag = "NAME",
		.question = "What is entrant's name?",
		.args = {
			.text = {
				.pattern = "^(.{1,75})$"
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_TEXT,
		.tag = "EMAIL",
		.question = "What is entrant's email address?",
		.args = {
			.text = {
				.pattern = "^(.*)+@(.*)+$"
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CERTIFICATE",
		.question = "Would you like to receive a certificate in the mail (if eligible)?",
		.args = {
			.choice = {
				.choices = qle_tmpl_cq_wpx_cw_certificate
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_TEXT,
		.tag = "GRID-LOCATOR",
		.question = "Maidenhead Grid Square of the station location?",
		.args = {
			.text = {
				.pattern = "^[A-R]{2}[0-9]{2}([A-X]{2})?$"
			}
		}
	},

	{
		.type = QLE_CABRILLO_TEMPLATE_DONE
	}
};

