/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>

#include "cabrillo.h"
#include "tmpl_qc_qso_party.h"

static char *qle_tmpl_qc_qso_party_category_operator[] = {
	"SINGLE-OP",
	"MULTI-OP",
	"CHECKLOG",
	NULL
};

static char *qle_tmpl_qc_qso_party_category_mode[] = {
	"SSB",
	"CW",
	"MIXED",
	NULL
};

static char *qle_tmpl_qc_qso_party_category_power[] = {
	"HIGH",
	"LOW",
	"QRP",
	NULL
};

static char *qle_tmpl_qc_qso_party_category_station[] = {
	"FIXED",
	"MOBILE",
	NULL
};

struct qle_cabrillo_template qle_tmpl_qc_qso_party[] = {
	{
		.type = QLE_CABRILLO_TEMPLATE_TEXT,
		.tag = "CALLSIGN",
		.question = "Which callsign was used during the contest?",
		.args = {
			.text = {
				.pattern = "^([A-Z0-9])+$"
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-OPERATOR",
		.question = "Which operator category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_qc_qso_party_category_operator
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-MODE",
		.question = "Which mode category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_qc_qso_party_category_mode
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-POWER",
		.question = "Which power category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_qc_qso_party_category_power
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_CHOICE,
		.tag = "CATEGORY-STATION",
		.question = "Which station category?",
		.args = {
			.choice = {
				.choices = qle_tmpl_qc_qso_party_category_station
			}
		}
	},
	{
		.type = QLE_CABRILLO_TEMPLATE_DONE
	}
};

