/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "../src/band.h"
#include "check.h"

#include <stdlib.h>
#include <string.h>

static int check_first(void) {
	char *band;
	band = qle_freq_to_band("0.1358");
	return strcmp(band, "2190M") == 0 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_middle(void) {
	char *band;
	band = qle_freq_to_band("144.200");
	return strcmp(band, "2M") == 0 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_last(void) {
	char *band;
	band = qle_freq_to_band("300000");
	return strcmp(band, "submM") == 0 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_low_edge(void) {
	char *band;
	band = qle_freq_to_band("21");
	return strcmp(band, "15M") == 0 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_high_edge(void) {
	char *band;
	band = qle_freq_to_band("21.45");
	return strcmp(band, "15M") == 0 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_not_found(void) {
	return qle_freq_to_band("107.1") == NULL ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

int main(int argc, char *argv[]) {

	static struct qle_check checks[] = {
		{ check_first, "qle_freq_to_band(\"0.1358\") --> \"2190M\"" },
		{ check_middle, "qle_freq_to_band(\"144.200\") --> \"2M\"" },
		{ check_last, "qle_freq_to_band(\"300000\") --> \"submM\"" },
		{ check_low_edge, "qle_freq_to_band(\"21\") --> \"15M\"" },
		{ check_high_edge, "qle_freq_to_band(\"21.45\") --> \"15M\"" },
		{ check_not_found, "qle_freq_to_band(\"107.1\") --> NULL" },
		{ NULL, NULL }
	};

	(void) argc;
	(void) argv;

	return qle_check(checks);
}
