/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "check.h"
#include "../src/str.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

static int check_trim_none(void) {
	char foo[32];
	snprintf(foo, 31, "foo");
	qle_trim(foo);
	return (strcmp(foo, "foo") == 0) ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_trim_left(void) {
	char foo[32];
	snprintf(foo, 31, " foo");
	qle_trim(foo);
	return (strcmp(foo, "foo") == 0) ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_trim_right(void) {
	char foo[32];
	snprintf(foo, 31, "foo ");
	qle_trim(foo);
	return (strcmp(foo, "foo") == 0) ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_trim_both(void) {
	char foo[32];
	snprintf(foo, 31, " foo ");
	qle_trim(foo);
	return (strcmp(foo, "foo") == 0) ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

int main(int argc, char *argv[]) {

	static struct qle_check checks[] = {
		{ check_trim_none, "trim(\"foo\") == \"foo\"" },
		{ check_trim_left, "trim(\"  foo\") == \"foo\"" },
		{ check_trim_right, "trim(\"foo \") == \"foo\"" },
		{ check_trim_both, "trim(\"  foo \") == \"foo\"" },
		{ NULL, NULL }
	};

	(void) argc;
	(void) argv;

	return qle_check(checks);
}
